document.addEventListener("DOMContentLoaded", function () {
  const favoriteButtons = document.querySelectorAll(".favorite-button");

  favoriteButtons.forEach((button) => {
    button.addEventListener("click", async function (e) {
      e.preventDefault();

      const reference = this.dataset.propertyReference;
      const isFavorited = this.dataset.favorited === "true";

      try {
        const response = await fetch(`/api/properties/${reference}/favorite`, {
          method: isFavorited ? "DELETE" : "POST",
          headers: {
            "Content-Type": "application/json",
            "x-csrf-token": document.querySelector("meta[name='csrf-token']")
              .content,
          },
        });

        const data = await response.json();

        if (response.ok) {
          this.textContent = isFavorited ? "☆" : "★";
          this.dataset.favorited = (!isFavorited).toString();
          showFlashMessage("success", data.message);
        } else {
          showFlashMessage("error", data.error);
        }
      } catch (error) {
        console.error("Error:", error);
        showFlashMessage("error", "Something went wrong");
      }
    });
  });
});

function showFlashMessage(type, message) {
  const flashContainer = document.createElement("div");
  flashContainer.className = `flash-message ${type}`;
  flashContainer.textContent = message;

  document.body.appendChild(flashContainer);

  setTimeout(() => {
    flashContainer.style.animation = "fadeOut 0.3s ease-out";
    flashContainer.addEventListener("animationend", () =>
      flashContainer.remove()
    );
  }, 3000);
}
