defmodule UserDeleteContext do
  use WhiteBread.Context
  use Hound.Helpers
  alias PropTrackr.Accounts
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User
  import PropTrackr.Authentication


  scenario_starting_state fn _state ->
    Ecto.Adapters.SQL.Sandbox.checkout(PropTrackr.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(PropTrackr.Repo, {:shared, self()})
    Hound.start_session()
    %{}
  end

  scenario_finalize fn _status, _state ->
    Ecto.Adapters.SQL.Sandbox.checkin(PropTrackr.Repo)
    Hound.end_session()
  end

  given_ ~r/^there exists following accounts$/, fn state, %{table_data: table} ->
    table
    |> Enum.map(fn user_details -> User.changeset(%User{}, user_details) end)
    |> Enum.each(fn changeset -> Repo.insert!(changeset) end)

    existing_user = List.first(table)
    {
      :ok,
      state
      |> Map.put(:email, existing_user[:email])
      |> Map.put(:password, existing_user[:password])
    }
  end

  and_ ~r/^I am logged in$/, fn state ->
    navigate_to("/login")

    fill_field({:id, "email"}, state[:email])
    fill_field({:id, "password"}, state[:password])

    click({:id, "login_button"})

    assert visible_in_page? ~r"Successfully logged in!"
    assert current_path() == "/"

    navigate_to("/users")

    {:ok, state}
  end


  and_ ~r/^I navigate to the delete account page$/, fn state ->
    navigate_to("/me/delete")
    {:ok, state}
  end

  when_ ~r/^I click confirm delete$/, fn state ->
    click({:id, "confirm_delete"})
    {:ok, state}
  end

  then_ ~r/^I should receive a success notification$/, fn state ->
    assert visible_in_page? ~r"Your account has been deleted successfully."
    {:ok, state}
  end


  and_ ~r/^I should be redirected to the homepage$/, fn state ->
    assert current_path() == "/"
    {:ok, state}
  end

  and_ ~r/^my account should no longer exist in the system$/, fn state ->
    user = Repo.get_by(User, email: state[:email])
    assert user == nil
    {:ok, state}
  end

  and_ ~r/^I am not logged in$/, fn state ->
    navigate_to("/logout")
    {:ok, state}

  end

  when_ ~r/^I try to access the delete functionality$/, fn state ->
    navigate_to("/me/delete")
    {:ok, state}
  end


  then_ ~r/^I should see an error message$/, fn state ->
    assert visible_in_page? ~r/You are not logged in!/
    {:ok, state}
  end

  and_ ~r/^I should be redirected to the login page$/, fn state ->
    assert current_path() == "/login"
    {:ok, state}
  end



end
