defmodule UserRegistrationContext do
  use WhiteBread.Context
  use Hound.Helpers
  alias PropTrackr.Accounts
  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User

  feature_starting_state fn ->
    Application.ensure_all_started(:hound)
    %{state: "initialized"}
  end

  scenario_starting_state fn _state ->
    Ecto.Adapters.SQL.Sandbox.checkout(PropTrackr.Repo)
    Ecto.Adapters.SQL.Sandbox.mode(PropTrackr.Repo, {:shared, self()})
    Hound.start_session()
    %{state: "session_started"}
  end

  scenario_finalize fn _status, _state ->
    Ecto.Adapters.SQL.Sandbox.checkin(PropTrackr.Repo)
    Hound.end_session()
  end

  given_ ~r/^I am on the registration page$/, fn state ->
    navigate_to("/register")
    {:ok, state}
  end

  when_ ~r/^I fill in the registration form with valid details$/, fn state ->
    fill_registration_form(
      "valid1@example.com",
      "Test",
      "User",
      "12.12.12",
      "1234567890",
      "test123",
      "test123"
    )
    {:ok, state}
  end

  and_ ~r/^I submit the form$/, fn state ->
    click({:id, "register_button"})
    {:ok, state}
  end

  then_ ~r/^I should see User created successfully.$/, fn state ->
    assert visible_in_page? ~r/User created successfully./
    {:ok, state}
  end

  and_ ~r/^I should be redirected to the homepage$/, fn state ->
    assert current_url() == "http://localhost:4001/users"
    {:ok, state}
  end

  when_ ~r/^I fill in the registration form with mismatched passwords$/, fn state ->
    fill_registration_form(
      "mismatch_user@example.com",
      "Mismatch",
      "User",
      "12.12.12",
      "1122334455",
      "test123",
      "different123"
    )
    {:ok, state}
  end

  then_ ~r/^I should see an error message Passwords do not match$/, fn state ->
    assert visible_in_page? ~r/Passwords do not match/
    {:ok, state}
  end

  # Helper function to fill out the registration form with 7 fields
  defp fill_registration_form(email, name, surname, birth_date, phone_number, password, confirm_password) do
    fill_field({:name, "user[email]"}, email)
    fill_field({:name, "user[name]"}, name)
    fill_field({:name, "user[surname]"}, surname)
    fill_field({:name, "user[birth_date]"}, birth_date)
    fill_field({:name, "user[phone_number]"}, phone_number)
    fill_field({:name, "user[password]"}, password)
    fill_field({:name, "user[confirm_password]"}, confirm_password)
  end

end
