defmodule PropTrackr.Accounts.User do
  use Ecto.Schema
  import Ecto.Changeset

  alias PropTrackr.Repo
  alias PropTrackr.Accounts.User

  schema "users" do
    field :name, :string
    field :surname, :string
    field :birth_date, :string
    field :phone_number, :string
    field :bio, :string
    field :email, :string
    field :password, :string
    field :confirm_password, :string, virtual: true  # Define confirm_password as virtual, not includes in database

    has_many :properties, PropTrackr.Properties.Property
    has_many :searches, PropTrackr.Search

    timestamps()
  end

  def changeset(struct, params \\ %{}) do
    struct
    |> cast(params, [:name, :surname, :birth_date, :phone_number, :bio, :email, :password, :confirm_password])
    |> validate_required([:name, :surname, :birth_date, :phone_number, :email, :password, :confirm_password])
    |> validate_password_confirmation(:password, :confirm_password)
    # |> validate_unique_email()
  end

  defp validate_password_confirmation(changeset, field_1, field_2) do
    if get_field(changeset, field_1) != get_field(changeset, field_2) do
      changeset
      |> add_error(field_2, "Passwords do not match.", [other: field_1])
    else
      changeset
    end
  end

  defp validate_unique_email(changeset) do
    email = get_field(changeset, :email)

    # Only check for uniqueness if email is not nil
    if email && Repo.get_by(User, email: email) do
      add_error(changeset, :email, "An account with this email already exists.")
    else
      changeset
    end
  end

end
