defmodule PropTrackrWeb.UserDeleteController do
  use PropTrackrWeb, :controller

  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo
  alias Ecto.Multi

  def index(conn, _params) do
    user_id = get_session(conn, :user_id)
    if user_id == nil do
      conn
      |> put_flash(:error, "You are not logged in!")
      |> redirect(to: ~p"/login")
    else
      user = Repo.get(User, user_id)
      render conn, "index.html"
    end
  end

  def delete(conn, _params) do
    user_id = get_session(conn, :user_id)
    user = Repo.get(User, user_id)

    if user do
      result =
        Multi.new()
          |> Multi.delete_all(:properties, Ecto.assoc(user, :properties))
          |> Multi.delete(:user, user)
          |> Repo.transaction()
      case result do
        {:ok, _} ->
          conn
          |> delete_session(:user_id)
          |> put_flash(:info, "Your account has been deleted successfully.")
          |> redirect(to: "/")
        {:error, _, _, _} ->
          conn
          |> put_flash(:error, "An error occurred while deleting your account.")
          |> redirect(to: "/me/delete")
      end
    else
      conn
      |> put_flash(:error, "User not found.")
      |> redirect(to: "/")
    end
  end
end
