defmodule PropTrackrWeb.ProfileControllerTest do
  use PropTrackrWeb.ConnCase
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  setup do
    user = %User{
      name: "Test",
      surname: "User",
      birth_date: "2000-01-01",
      phone_number: "000",
      bio: "Yo",
      email: "test.user@gmail.com",
      password: "testing",
      confirm_password: "testing",
    }
    user = Repo.insert!(user)

    {:ok, %{user: user}}
  end

  test "Authenticated user should see their data on the profile page", %{conn: conn, user: user} do
    conn = conn |> setup_session(user)
    conn = get conn, "/me"
    assert html_response(conn, 200) =~ ~r/#{user.name} #{user.surname}'s profile/
    assert html_response(conn, 200) =~ ~r/#{user.email}/
    assert html_response(conn, 200) =~ ~r/#{user.phone_number}/
    assert html_response(conn, 200) =~ ~r/#{user.bio}/
    assert html_response(conn, 200) =~ ~r/#{user.birth_date}/
  end

  test "Unauthenticated user should see an error message", %{conn: conn} do
    conn = get conn, "/me"
    assert redirected_to(conn) == "/login"
    conn = get conn, redirected_to(conn)
    assert html_response(conn, 200) =~ ~r/You are not logged in!/
  end

  test "Unauthenticated user should be redirected to the login page", %{conn: conn} do
    conn = get conn, "/me"
    assert redirected_to(conn) == "/login"
  end

  defp setup_session(conn, user) do
    conn = conn |> post("/login", email: user.email, password: user.password)
    conn = get conn, redirected_to(conn)
    conn
  end
end
