defmodule PropTrackrWeb.UserControllerTest do
  use PropTrackrWeb.ConnCase
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  setup do
    {:ok, user_params: %{
      name: "Test User",
      surname: "Doe",
      birth_date: "1990-01-01",
      phone_number: "123-456-7890",
      bio: "This is a test bio.",
      email: "new_user@example.com",
      password: "test123",
      confirm_password: "test123"
    }}
  end

  test "AC1: unauthenticated user can register an account", %{conn: conn, user_params: user_params} do
    conn = post(conn, "/register",  user: user_params)
    assert html_response(conn, 302)
    assert get_flash(conn, :info) == "User created successfully."
    assert redirected_to(conn) == "/users"
  end

  test "AC2 and AC3: user sees an error when passwords do not match", %{conn: conn, user_params: user_params} do
    mismatched_params = Map.put(user_params, :confirm_password, "different_password")
    conn = post(conn, "/register", user: mismatched_params)
    assert html_response(conn, 200) =~ "Passwords do not match."
  end

  # TODO(Kerdo): Reintroduce this test when re-enabling already existing email constraint
  @tag :skip
  test "AC4: user sees an error if an account with the same email exists", %{conn: conn, user_params: user_params} do
    Repo.insert!(%User{email: user_params[:email], password: "test123"})
    conn = post(conn, "/register", user: user_params)
    assert html_response(conn, 200) =~ "An account with this email already exists"
  end

  test "AC5, AC6, AC7: user is logged in, redirected, and shown notification upon successful registration", %{conn: conn, user_params: user_params} do
    conn = post(conn, "/register", user: user_params)
    assert get_flash(conn, :info) == "User created successfully."
    assert redirected_to(conn) == "/users"
    assert get_session(conn, :user_id)
  end
end
