defmodule PropTrackrWeb.UserDeleteControllerTest do
  use PropTrackrWeb.ConnCase
  alias PropTrackr.Accounts.User
  alias PropTrackr.Repo

  @valid_attrs %{email: "test.user@gmail.com", password: "testing"}

  setup do
    user = %User{
      name: "Test",
      surname: "User",
      birth_date: "2000-01-01",
      phone_number: "000",
      bio: "Yo",
      email: "test.user@gmail.com",
      password: "testing",
      confirm_password: "testing",
    }
    user = Repo.insert!(user)

    {:ok, %{user: user}}
  end

  test "Authenticated user should be able to delete their account and be redirected to the homepage and logged out and data deleted", %{conn: conn, user: user} do
    # Log in the user
    conn = setup_session(conn, user)

    # Ensure the user is logged in
    assert get_session(conn, :user_id) == user.id

    # Perform delete with the user ID in the route
    conn = delete(conn, "/me/delete/#{user.id}")

    # Verify redirection to homepage
    assert redirected_to(conn) == "/"

    # Follow the redirection
    conn = get(conn, redirected_to(conn))
    assert html_response(conn, 200)

    # Ensure the response contains the correct flash message
    assert get_flash(conn, :info) =~ "Your account has been deleted successfully."

    # Verify the user is logged out
    assert get_session(conn, :user_id) == nil

    # Confirm the user's data is removed from the database
    assert Repo.get(User, user.id) == nil
  end

  test "Unauthenticated user cannot access the delete page", %{conn: conn} do
    # Attempt to access the delete account page
    conn = get(conn, "/me/delete")

    # Verify redirection to homepage
    assert redirected_to(conn) == "/login"

    # Follow the redirection
    conn = get(conn, redirected_to(conn))

    assert html_response(conn, 200)

  end



  defp setup_session(conn, user) do
    conn = conn |> post("/login", @valid_attrs)
    conn = get conn, redirected_to(conn)
    conn
  end

end
